@@ -428,9 +428,9 @@ namespace Dune
         topologyId, CoordType, coerceToId, dim,
         typename std::enable_if<
             (dim >= 2 &&
-             (Impl::CubeTopology<dim>::type::id >> 1) ==
+             (GeometryTypes::cube(dim).id() >> 1) ==
              (topologyId >> 1) &&
-             (Impl::CubeTopology<dim>::type::id >> 1) ==
+             (GeometryTypes::cube(dim).id() >> 1) ==
              (coerceToId >> 1)
             )>::type
         >
