@@ -218,7 +218,7 @@ namespace Dune
       {
         std::vector<CoordVector> corners(1);
         corners[0] = referenceToKuhn(backend.coords(), getPermutation<dimension>(kuhnIndex));
-        return Geometry(GeometryType(0), corners);
+        return Geometry(GeometryTypes::vertex, corners);
       }
 
       template<int dimension, class CoordType>
@@ -399,9 +399,9 @@ namespace Dune
         topologyId, CoordType, coerceToId, dim,
         typename std::enable_if<
             (dim >= 2 &&
-             (Impl::CubeTopology<dim>::type::id >> 1) ==
+             (GeometryTypes::cube(dim).id() >> 1) ==
              (topologyId >> 1) &&
-             (Impl::SimplexTopology<dim>::type::id >> 1) ==
+             (GeometryTypes::simplex(dim).id() >> 1) ==
              (coerceToId >> 1)
             )>::type
         >
