@@ -221,7 +221,7 @@ namespace Dune
         std::vector<CoordVector> corners(1);
         corners[0] = transformCoordinate(referenceToKuhn(backend.coords(),
                                                          getPermutation<dimension>((kuhnIndex + 2) % 4)));
-        return Geometry(GeometryType(0), corners);
+        return Geometry(GeometryTypes::vertex, corners);
       }
 
       template<int dimension, class CoordType>
@@ -394,9 +394,9 @@ namespace Dune
     struct Traits<
         topologyId, CoordType, coerceToId, 3,
         typename std::enable_if<
-            (Impl::PrismTopology<3>::type::id >> 1) ==
+            (GeometryTypes::prism.id() >> 1) ==
             (topologyId >> 1) &&
-            (Impl::SimplexTopology<3>::type::id >> 1) ==
+            (GeometryTypes::simplex(3).id() >> 1) ==
             (coerceToId >> 1)
             >::type>
     {
