@@ -2,6 +2,8 @@
 
 #include <iostream>
 
+#include <dune/common/deprecated.hh>
+
 #include <dune/geometry/type.hh>
 
 int main ( int argc, char **argv )
@@ -9,7 +11,9 @@ int main ( int argc, char **argv )
   int fail = 0;
   for( int dim = 0; dim < 10; ++dim )
   {
+DUNE_NO_DEPRECATED_BEGIN
     Dune::GeometryType gt1( Dune::GeometryType::none, dim );
+DUNE_NO_DEPRECATED_END
     Dune::GeometryType gt2 = Dune::GeometryTypes::none( dim );
 
     if ( ! gt1.isNone() )
