@@ -493,7 +493,7 @@ namespace Dune
     try {
       return backend == dynamic_cast<const This &>(other).backend;
     }
-    catch(std::bad_cast)
+    catch(const std::bad_cast&)
     {
       return false;
     }
@@ -567,8 +567,8 @@ namespace Dune
       topologyId &= ~1;
       coerceToId &= ~1;
 
-      const unsigned idSimplex = Impl::SimplexTopology<dimension>::type::id & ~1;
-      const unsigned idCube = Impl::CubeTopology<dimension>::type::id & ~1;
+      const unsigned idSimplex = GeometryTypes::simplex(dimension).id() & ~1;
+      const unsigned idCube = GeometryTypes::cube(dimension).id() & ~1;
 
       switch( topologyId )
       {
@@ -618,7 +618,7 @@ namespace Dune
       topologyId &= ~1;
       coerceToId &= ~1;
 
-      const unsigned idSimplex = Impl::SimplexTopology<dimension>::type::id & ~1;
+      const unsigned idSimplex = GeometryTypes::simplex(dimension).id() & ~1;
 
       if (topologyId == 0 && coerceToId == 0)
         return VirtualRefinementImp< idSimplex, CoordType, idSimplex, dimension>::instance();
@@ -640,10 +640,10 @@ namespace Dune
       topologyId &= ~1;
       coerceToId &= ~1;
 
-      const unsigned idSimplex = Impl::SimplexTopology<dimension>::type::id & ~1;
-      const unsigned idCube = Impl::CubeTopology<dimension>::type::id & ~1;
-      const unsigned idPrism = Impl::PrismTopology<dimension>::type::id & ~1;
-      const unsigned idPyramid = Impl::PyramidTopology<dimension>::type::id & ~1;
+      const unsigned idSimplex = GeometryTypes::simplex(dimension).id() & ~1;
+      const unsigned idCube = GeometryTypes::cube(dimension).id() & ~1;
+      const unsigned idPrism = GeometryTypes::prism.id() & ~1;
+      const unsigned idPyramid = GeometryTypes::pyramid.id() & ~1;
 
       switch( topologyId )
       {
